pub struct CliCipher(/* private fields */);Methods from Deref<Target = Cipher>
sourcepub fn block_size(&self) -> usize
pub fn block_size(&self) -> usize
Returns the block size of the cipher.
sourcepub fn tag_size(&self) -> u32
pub fn tag_size(&self) -> u32
Returns the tag size of the cipher.
An AE-cipher results into a
- ciphertext
- tag
Ciphertext and tag are both stored in a block of the container. Use
this method to get the size of the tag. For a non-AE-cipher the
tag-size is 0.
pub fn decrypt<B>( &self, input: &[u8], output: &mut Vec<u8>, key: &[u8], iv: &[u8] ) -> Result<usize, Error<B>>where B: Backend,
pub fn encrypt<B>( &self, input: &[u8], output: &mut Vec<u8>, key: &[u8], iv: &[u8] ) -> Result<usize, Error<B>>where B: Backend,